@@ -641,10 +641,15 @@ check_for_bases <- function(pop) {
   using_sequencing_data <- FALSE
   # sum has to be at least 4, 0 represents missing data, but
   # might not be in the data
+
   if (sum(unique_bases %in% c(0, 1, 2, 3, 4)) >= 4 &&
       sum(unique_bases %in% c(0, 1, 2, 3, 4)) <= 5) {
     using_sequencing_data <- TRUE
   }
+  if (sum(!unique_bases %in% c(0, 1, 2, 3, 4)) > 0) {
+    using_sequencing_data <- FALSE
+  }
+
   return(using_sequencing_data)
 }
 
