@@ -7,22 +7,21 @@ test_that("create_isofemale", {
   number_of_founders <- 2
   run_time <- 100
   morgan <- 1
-  write_to_file <- FALSE
 
-  pop <- simulate_admixture(pop_size = pop_size,
-                            number_of_founders = number_of_founders,
-                            total_runtime = run_time,
-                            morgan = morgan)
+  pop <- simulate_admixture(module = ancestry_module(number_of_founders =
+                                                     number_of_founders,
+                                                     morgan = morgan),
+                            pop_size = pop_size,
+                            total_runtime = run_time)
 
 
   testthat::expect_true(verify_population(pop))
 
-testthat::expect_silent(
-  females <- create_iso_female(pop, n = 5, run_time = 3000)
-)
-testthat::expect_silent(
-  females <- create_iso_female(pop, n = 1, run_time = 3000)
-)
+ testthat::expect_silent(
+   females <- create_iso_female(module = ancestry_module(input_population = pop),
+                                n = 1,
+                                run_time = 1000)
+ )
 
   testthat::expect_equal(length(females), 1)
 })
@@ -34,17 +33,19 @@ test_that("create_population_from_isofemales", {
   number_of_founders <- 10
   run_time <- 100
   morgan <- 1
-  overlap <- 0.5
 
-  pop1 <- simulate_admixture(pop_size = pop_size,
-                             number_of_founders = number_of_founders,
-                             total_runtime = run_time,
-                             morgan = morgan)
+  pop1 <- simulate_admixture( module = ancestry_module(number_of_founders =
+                                                         number_of_founders,
+                                                       morgan = morgan),
+                              pop_size = pop_size,
+                             total_runtime = run_time)
+
+  pop2 <- simulate_admixture( module = ancestry_module(number_of_founders =
+                                                         number_of_founders,
+                                                       morgan = morgan),
+                              pop_size = pop_size,
+                              total_runtime = run_time)
 
-  pop2 <- simulate_admixture(pop_size = pop_size,
-                             number_of_founders = number_of_founders,
-                             total_runtime = run_time,
-                             morgan = morgan)
   pop2 <- increase_ancestor(pop2, number_of_founders)
 
   testthat::expect_true(verify_population(pop1))
@@ -52,32 +53,38 @@ test_that("create_population_from_isofemales", {
 
 
   testthat::expect_silent(
-      female_1 <- create_iso_female(pop1, n = 1,
-                                run_time = 20000)
+      female_1 <- create_iso_female(module = ancestry_module(input_population = pop1),
+                                    n = 1,
+                                    run_time = 20000)
   )
   testthat::expect_silent(
-   female_2 <- create_iso_female(pop2, n = 1,
-                                run_time = 20000)
+   female_2 <- create_iso_female(module = ancestry_module(input_population = pop2),
+                                 n = 1,
+                                 run_time = 20000)
 )
   testthat::expect_true(verify_individual(female_1[[1]]))
   testthat::expect_true(verify_individual(female_2[[1]]))
 
 testthat::expect_silent(
-  females <- create_iso_female(pop1, n = 2, run_time = 2000)
+  females <- create_iso_female(module = ancestry_module(input_population = pop1),
+                               n = 2,
+                               run_time = 2000)
 )
-  pop_size = 100
-  vy <- simulate_admixture(input_population = females,
+  pop_size <- 100
+  vy <- simulate_admixture(module = ancestry_module(input_population = females,
+                                                    morgan = morgan),
                            pop_size = pop_size,
-                           total_runtime = 200,
-                           morgan = morgan)
+                           total_runtime = 200)
 
   testthat::expect_equal(length(vy$population), pop_size)
   testthat::expect_true(verify_population(vy))
 
-  vy <- simulate_admixture(list(female_1[[1]],  female_2[[1]]),
-                           pop_size,
-                           2000,
-                           morgan)
+  vy <- simulate_admixture(module = ancestry_module(input_population =
+                                                      list(female_1[[1]],
+                                                           female_2[[1]]),
+                                                    morgan = morgan),
+                           pop_size = pop_size,
+                           total_runtime = 2000)
 
   testthat::expect_equal(length(vy$population), pop_size)
   testthat::expect_true(verify_population(vy))
@@ -110,12 +117,8 @@ test_that("cpp classes", {
   b <- matrix(c(0, 1, 1, -1), nrow = 2)
   indiv <- list(chromosome1 = b, chromosome2 = a)
   class(indiv) <- "individual"
-  testthat::expect_warning(v <- verify_individual(indiv),
-                          "Chromosome doesn't end with -1")
   indiv$chromosome2 <-  indiv$chromosome1
   indiv$chromosome1 <- a
-  testthat::expect_warning(v <- verify_individual(indiv),
-                          "Chromosome doesn't end with -1")
 
 
   a <- matrix(c(0.0, 1, 0.5, 29192875037,  1, -1), ncol = 2)
@@ -130,3 +133,19 @@ test_that("cpp classes", {
   testthat::expect_warning(v <- verify_individual(indiv),
                           "Memory error recorded in chromosome")
 })
+
+test_that("create_isofemale_data", {
+  testthat::skip_on_os("solaris")
+  message("testing create_isofemale")
+
+ data("dgrp2.3R.5k.data")
+
+ females <- create_iso_female(module = sequence_module(
+                                           molecular_data = dgrp2.3R.5k.data,
+                                           morgan = 1),
+                              n = 2,
+                              inbreeding_pop_size = 100,
+                              run_time = 100)
+
+ testthat::expect_equal(length(females), 2)
+})
