@@ -2,18 +2,15 @@
 test_that("expected_number_junctions", {
   testthat::skip_on_os("solaris")
   message("test expected_number_junctions")
-#  skip("skip junctions")
   test_expected_junction_number <- function(pop_size,
                                             run_time,
                                             morgan,
                                             replicates) {
     found <- c()
     for (r in 1:replicates) {
-      vx <- simulate_admixture(pop_size = pop_size,
-                               number_of_founders = 2,
-                               total_runtime = run_time,
-                               morgan = morgan,
-                               verbose = FALSE)
+      vx <- simulate_admixture(module = ancestry_module(morgan = morgan),
+                               pop_size = pop_size,
+                               total_runtime = run_time)
 
       junct <- calculate_dist_junctions(vx$population)
       found <- c(found, mean(junct))
@@ -29,16 +26,16 @@ test_that("expected_number_junctions", {
   }
 
   test_expected_junction_number(pop_size = 1000, run_time = 20,
-                                morgan = 1, replicates = 20)
+                                morgan = 1, replicates = 100)
 
-  test_expected_junction_number(pop_size = 1000, run_time = 100,
-                                morgan = 0.5, replicates = 30)
+  test_expected_junction_number(pop_size = 1000, run_time = 20,
+                                morgan = 0.5, replicates = 100)
 
-  test_expected_junction_number(pop_size = 1000, run_time = 100,
-                                morgan = 3, replicates = 30)
+  test_expected_junction_number(pop_size = 1000, run_time = 20,
+                                morgan = 3, replicates = 100)
 
-  vx <- simulate_admixture(pop_size = 100, number_of_founders = 2,
-                          total_runtime = 5, morgan = 1)
+  vx <- simulate_admixture(pop_size = 100,
+                           total_runtime = 5)
 
   plot_dist_junctions(vx$population)
 })
